@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 # Redmine - project management software
-# Copyright (C) 2006-2019  Jean-Philippe Lang
+# Copyright (C) 2006-2021  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -40,7 +40,9 @@ class IssueRelationsControllerTest < Redmine::ControllerTest
 
   def test_create
     assert_difference 'IssueRelation.count' do
-      post :create, :params => {
+      post(
+        :create,
+        :params => {
           :issue_id => 1,
           :relation => {
             :issue_to_id => '2',
@@ -48,6 +50,7 @@ class IssueRelationsControllerTest < Redmine::ControllerTest
             :delay => ''
           }
         }
+      )
     end
     relation = IssueRelation.order('id DESC').first
     assert_equal 1, relation.issue_from_id
@@ -57,7 +60,9 @@ class IssueRelationsControllerTest < Redmine::ControllerTest
 
   def test_create_on_invalid_issue
     assert_no_difference 'IssueRelation.count' do
-      post :create, :params => {
+      post(
+        :create,
+        :params => {
           :issue_id => 999,
           :relation => {
             :issue_to_id => '2',
@@ -65,13 +70,16 @@ class IssueRelationsControllerTest < Redmine::ControllerTest
             :delay => ''
           }
         }
+      )
       assert_response 404
     end
   end
 
   def test_create_xhr
     assert_difference 'IssueRelation.count' do
-      post :create, :params => {
+      post(
+        :create,
+        :params => {
           :issue_id => 3,
           :relation => {
             :issue_to_id => '1',
@@ -80,8 +88,9 @@ class IssueRelationsControllerTest < Redmine::ControllerTest
           }
         },
         :xhr => true
+      )
       assert_response :success
-      assert_equal 'text/javascript', response.content_type
+      assert_equal 'text/javascript', response.media_type
     end
     relation = IssueRelation.order('id DESC').first
     assert_equal 1, relation.issue_from_id
@@ -92,7 +101,9 @@ class IssueRelationsControllerTest < Redmine::ControllerTest
 
   def test_create_should_accept_id_with_hash
     assert_difference 'IssueRelation.count' do
-      post :create, :params => {
+      post(
+        :create,
+        :params => {
           :issue_id => 1,
           :relation => {
             :issue_to_id => '#2',
@@ -100,6 +111,7 @@ class IssueRelationsControllerTest < Redmine::ControllerTest
             :delay => ''
           }
         }
+      )
     end
     relation = IssueRelation.order('id DESC').first
     assert_equal 2, relation.issue_to_id
@@ -107,7 +119,9 @@ class IssueRelationsControllerTest < Redmine::ControllerTest
 
   def test_create_should_strip_id
     assert_difference 'IssueRelation.count' do
-      post :create, :params => {
+      post(
+        :create,
+        :params => {
           :issue_id => 1,
           :relation => {
             :issue_to_id => ' 2  ',
@@ -115,6 +129,7 @@ class IssueRelationsControllerTest < Redmine::ControllerTest
             :delay => ''
           }
         }
+      )
     end
     relation = IssueRelation.order('id DESC').first
     assert_equal 2, relation.issue_to_id
@@ -123,7 +138,9 @@ class IssueRelationsControllerTest < Redmine::ControllerTest
   def test_create_should_not_break_with_non_numerical_id
     assert_no_difference 'IssueRelation.count' do
       assert_nothing_raised do
-        post :create, :params => {
+        post(
+          :create,
+          :params => {
             :issue_id => 1,
             :relation => {
               :issue_to_id => 'foo',
@@ -131,16 +148,21 @@ class IssueRelationsControllerTest < Redmine::ControllerTest
               :delay => ''
             }
           }
+        )
       end
     end
   end
 
   def test_create_follows_relation_should_update_relations_list
-    issue1 = Issue.generate!(:subject => 'Followed issue', :start_date => Date.yesterday, :due_date => Date.today)
+    issue1 = Issue.generate!(:subject => 'Followed issue',
+                             :start_date => Date.yesterday,
+                             :due_date => Date.today)
     issue2 = Issue.generate!
 
     assert_difference 'IssueRelation.count' do
-      post :create, :params => {
+      post(
+        :create,
+        :params => {
           :issue_id => issue2.id,
           :relation => {
             :issue_to_id => issue1.id,
@@ -149,29 +171,36 @@ class IssueRelationsControllerTest < Redmine::ControllerTest
           }
         },
         :xhr => true
+      )
     end
     assert_include 'Followed issue', response.body
   end
 
   def test_should_create_relations_with_visible_issues_only
-    Setting.cross_project_issue_relations = '1'
-    assert_nil Issue.visible(User.find(3)).find_by_id(4)
+    with_settings :cross_project_issue_relations => '1' do
+      assert_nil Issue.visible(User.find(3)).find_by_id(4)
 
-    assert_no_difference 'IssueRelation.count' do
-      post :create, :params => {
-          :issue_id => 1,
-          :relation => {
-            :issue_to_id => '4',
-            :relation_type => 'relates',
-            :delay => ''
+      assert_no_difference 'IssueRelation.count' do
+        post(
+          :create,
+          :params => {
+            :issue_id => 1,
+            :relation => {
+              :issue_to_id => '4',
+              :relation_type => 'relates',
+              :delay => ''
+            }
           }
-        }
+        )
+      end
     end
   end
 
   def test_create_xhr_with_failure
     assert_no_difference 'IssueRelation.count' do
-      post :create, :params => {
+      post(
+        :create,
+        :params => {
           :issue_id => 3,
           :relation => {
             :issue_to_id => '999',
@@ -180,26 +209,69 @@ class IssueRelationsControllerTest < Redmine::ControllerTest
           }
         },
         :xhr => true
-
+      )
       assert_response :success
-      assert_equal 'text/javascript', response.content_type
+      assert_equal 'text/javascript', response.media_type
     end
     assert_include 'Related issue cannot be blank', response.body
   end
 
+  def test_bulk_create_with_multiple_issue_to_id_issues
+    assert_difference 'IssueRelation.count', +3 do
+      post :create, :params => {
+        :issue_id => 1,
+        :relation => {
+          # js autocomplete adds a comma at the end
+          # issue to id should accept both id and hash with id
+          :issue_to_id => '2,3,#7, ',
+          :relation_type => 'relates',
+          :delay => ''
+        }
+      },
+      :xhr => true
+    end
+
+    assert_response :success
+    relations = IssueRelation.where(:issue_from_id => 1, :issue_to_id => [2, 3, 7])
+    assert_equal 3, relations.count
+    # all relations types should be 'relates'
+    relations.map {|r| assert_equal 'relates', r.relation_type}
+
+    # no error messages should be returned in the response
+    assert_not_include 'id=\"errorExplanation\"', response.body
+  end
+
+  def test_bulk_create_should_show_errors
+    assert_difference 'IssueRelation.count', +3 do
+      post :create, :params => {
+        :issue_id => 1,
+        :relation => {
+          :issue_to_id => '1,2,3,4,5,7',
+          :relation_type => 'relates',
+          :delay => ''
+        }
+      },
+      :xhr => true
+    end
+
+    assert_response :success
+    assert_equal 'text/javascript', response.media_type
+    # issue #1 is invalid
+    assert_include 'Related issue is invalid: #1', response.body
+    # issues #4 and #5 can't be related by default
+    assert_include 'Related issue cannot be blank', response.body
+    assert_include 'Related issue doesn&#39;t belong to the same project', response.body
+  end
+
   def test_destroy
     assert_difference 'IssueRelation.count', -1 do
-      delete :destroy, :params => {
-          :id => '2'
-        }
+      delete(:destroy, :params => {:id => '2'})
     end
   end
 
   def test_destroy_invalid_relation
     assert_no_difference 'IssueRelation.count' do
-      delete :destroy, :params => {
-          :id => '999'
-        }
+      delete(:destroy, :params => {:id => '999'})
       assert_response 404
     end
   end
@@ -211,13 +283,9 @@ class IssueRelationsControllerTest < Redmine::ControllerTest
     end
 
     assert_difference 'IssueRelation.count', -1 do
-      delete :destroy, :params => {
-          :id => '2'
-        },
-        :xhr => true
-
+      delete(:destroy, :params => {:id => '2'}, :xhr => true)
       assert_response :success
-      assert_equal 'text/javascript', response.content_type
+      assert_equal 'text/javascript', response.media_type
       assert_include 'relation-2', response.body
     end
   end
